@@ -30,11 +30,6 @@ async def print_message(msg):
     print(msg)
 
 
-@sio.on("designate")
-async def designate(virtual_ip):
-    print(f"Virtual address: {virtual_ip}")
-
-
 @sio.on("connect")
 async def on_connect():
     print("connected to server")
